#
# spec file for package kf6-kstatusnotifieritem
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.8.0

%define rname kstatusnotifieritem

%bcond_without kde_python_bindings
%if %{with kde_python_bindings}
%if 0%{suse_version} > 1500
%define pythons %{primary_python}
%else
%{?sle15_python_module_pythons}
%endif
%define mypython %pythons
%define __mypython %{expand:%%__%{mypython}}
%define mypython_sitearch %{expand:%%%{mypython}_sitearch}
%endif

# Full KF6 version (e.g. 6.15.0)
%{!?_kf6_version: %global _kf6_version %{version}}
%bcond_without released
Name:           kf6-kstatusnotifieritem
Version:        6.15.0
Release:        1.1
Summary:        Implementation of Status Notifier Items
License:        LGPL-2.0-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_version}
BuildRequires:  qt6-widgets-private-devel
BuildRequires:  cmake(KF6WindowSystem) >= %{_kf6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
# SECTION bindings
%if %{with kde_python_bindings}
BuildRequires:  %{mypython}-build
BuildRequires:  %{mypython}-devel >= 3.9
BuildRequires:  %{mypython}-setuptools
BuildRequires:  %{mypython}-wheel
BuildRequires:  cmake(Shiboken6)
BuildRequires:  cmake(PySide6)
%endif
# /SECTION

%description
Implementation of Status Notifier Items.

%package -n libKF6StatusNotifierItem6
Summary:        Implementation of Status Notifier Items
Requires:       kf6-kstatusnotifieritem >= %{version}

%description -n libKF6StatusNotifierItem6
Implementation of Status Notifier Items.

%package devel
Summary:        Development files for kstatusnotifieritem
Requires:       libKF6StatusNotifierItem6 = %{version}
Requires:       cmake(Qt6DBus) >= %{qt6_version}
Requires:       cmake(Qt6Gui) >= %{qt6_version}
Requires:       cmake(Qt6Widgets) >= %{qt6_version}
Requires:       cmake(Qt6Xml) >= %{qt6_version}

%description devel
Development files for kstatusnotifieritem

%if %{with kde_python_bindings}
%package -n python3-kf6-kstatusnotifieritem
Summary:        Python interface for kf6-kstatusnotifieritem

%description -n python3-kf6-kstatusnotifieritem
This package provides a python interface for kf6-kstatusnotifieritem.
%endif

%lang_package -n libKF6StatusNotifierItem6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 \
%if %{with kde_python_bindings}
  -DPython_EXECUTABLE:STRING=%{__mypython}
%endif
%{nil}

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang kstatusnotifieritem6 --with-qt

%ldconfig_scriptlets -n libKF6StatusNotifierItem6

%files
%{_kf6_debugdir}/kstatusnotifieritem.categories

%files -n libKF6StatusNotifierItem6
%license LICENSES/*
%{_kf6_libdir}/libKF6StatusNotifierItem.so.*

%files devel
%{_kf6_libdir}/libKF6StatusNotifierItem.so
%{_kf6_cmakedir}/KF6StatusNotifierItem/
%{_kf6_dbusinterfacesdir}/kf6_org.kde.StatusNotifierItem.xml
%{_kf6_dbusinterfacesdir}/kf6_org.kde.StatusNotifierWatcher.xml
%{_kf6_includedir}/KStatusNotifierItem/

%if %{with kde_python_bindings}
%files -n python3-kf6-kstatusnotifieritem
%{mypython_sitearch}/*.so
%endif

%files -n libKF6StatusNotifierItem6-lang -f kstatusnotifieritem6.lang

%changelog
* Mon Jun  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.15.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.15.0
- Changes since 6.14.0:
  * Update dependency version to 6.15.0
  * Disable python bindings for Haiku also
  * Build Python bindings unless explicitly disabled
  * Add tags file to documentation
  * Fix typo in qdocconf file
  * Add landing page for QDoc
  * It compiles fine without kf_6_13 deprecated methods
  * Port API documentation to QDoc syntax
  * Remove pre-Qt 6.7 workaround
  * Update version to 6.15.0
- Replace _kf6_bugfix_version usage
* Sun May  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.14.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.14.0
- Changes since 6.13.0:
  * Update dependency version to 6.14.0
  * Update version to 6.14.0
  * Remove recommendation to not use setContextMenu
  * Add KStatusNotifierItem::isMenu
  * .gitignore ignore "/compile_commands.json"
* Sat Apr  5 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.13.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.13.0
- Changes since 6.12.0:
  * It compiles fine without qt6.9 deprecated methods
  * It compiles fine without kf6.12 deprecated methods
  * Update dependency version to 6.13.0
* Tue Mar 11 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.12.0
- Changes since 6.11.0:
  * Update dependency version to 6.12.0
  * Do not crash if KDE platform integration is loaded but SNI is unavailable (kde#350785)
  * Update version to 6.12.0
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * Fix build with Qt 6.10
  * Add xml/yaml linting
  * Add Python bindings
  * CI: Add linux-qt6-next build
  * Fix svg icons
  * Update version to 6.11.0
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * It compiles fine without deprecated methods
  * ci: add Alpine/musl job
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Fix absolute path generation in (not installed) header
  * typo--
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Document flatpak manifest requirements
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * Fix deprecation versions
  * Deprecate action collection access
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Add API to control quit behavior
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * support USE_DBUS option to enable/disable dbus use
  * gitignore: add VS Code dir
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- No code changes since 6.2.0
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- No code change since 6.1.0
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Improve activating associated window on Wayland
* Thu Feb 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * Link privately against Qt6::WidgetsPrivate
  * update version for new release
  * Work around show/hide on widget windows
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Fri Aug 18 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kstatusnotifieritem
